#Code used in the manuscript: Increasing the number of stressors reduces soil ecosystem services worldwide 

#Code author Miguel Berdugo

library(ggplot2)
library(MuMIn)
library(dplyr)
library(reshape2)
library(relaimpo)
library(MASS)
library(simpleboot)
library(corrplot)
library(sf)                # Simple Features for GIS

library(rnaturalearth)     # package with detailed information about country &
library(rnaturalearthdata) # state/province borders, and geographical features


##Figure 1 (maps)
df=read.csv("locations_Map_S1.csv")
world_map <- 
  ne_countries(returnclass = 'sf') 
library(ggforce)
library(gridExtra)
pa<-ggplot(data=world_map) + 
  geom_sf(fill='white',size=.2) +
  theme(panel.background = element_rect(fill = "lightblue",
                                        colour = "lightblue",
                                        size = 0.5, linetype = "solid"),
        axis.title = element_blank(),
        axis.text = element_blank())+
  scale_x_continuous(expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0))+
  ylim(-55,90)+
  geom_point(data = df[df$Data=="Global 1a",],aes(x=Longitude,y=Latitude),shape=21,fill="red",size=1)
pb<-ggplot(data=world_map) + 
  geom_sf(fill='white',size=.2) +
  theme(panel.background = element_rect(fill = "lightblue",
                                        colour = "lightblue",
                                        size = 0.5, linetype = "solid"),
        axis.title = element_blank(),
        axis.text = element_blank())+
  scale_x_continuous(expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0))+
  ylim(-55,90)+
  geom_point(data = df[df$Data=="Global 1b",],aes(x=Longitude,y=Latitude),shape=21,fill="red",size=1)

pc<-ggplot(data=world_map) + 
  geom_sf(fill='white',size=.2) +
  theme(panel.background = element_rect(fill = "lightblue",
                                        colour = "lightblue",
                                        size = 0.5, linetype = "solid"),
        axis.title = element_blank(),
        axis.text = element_blank())+
  scale_x_continuous(expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0))+
  ylim(-55,90)+
  geom_point(data = df[df$Data=="Global 2",],aes(x=Longitude,y=Latitude),shape=21,fill="red",size=1)

PP1=grid.arrange(pa, pb,pc, nrow = 3)

ggsave("Figure1.tiff",PP1,device="tiff",units = "cm",width = 12,height = 16,dpi = 350)

library(ggplot2)
library(MuMIn)
library(dplyr)
library(reshape2)
library(relaimpo)
library(MASS)
library(simpleboot)
library(corrplot)

##NEW VARS
df1a=read.csv("GDF1.v4.csv")
MS1a=df1a[,c(17:23)]
MS1a=as.data.frame(lapply(MS1a, function(x) return(100*(x- quantile(x,0.05))/(quantile(x,0.95)-quantile(x,0.05)))))

df1b=df1a[!is.na(df1a$MP),]
MS1b=df1b[,c(17:25)]
MS1b=as.data.frame(lapply(MS1b, function(x) return(100*(x- quantile(x,0.05))/(quantile(x,0.95)-quantile(x,0.05)))))

df2=read.csv("GDF2.v4.csv")
MS2=df2[,c(14:20)]
MS2=as.data.frame(lapply(MS2, function(x) return(100*(x- quantile(x,0.05))/(quantile(x,0.95)-quantile(x,0.05)))))

##organize dataframes in a list structure


DATAFRAMES=list(global1a=list(df=df1a,MS=MS1a),
                global1b=list(df=df1b,MS=MS1b),
                global2=list(df=df2,MS=MS2))

###Analyses related to figure 1 and supp table 3
set.seed(100)
super.RES=lapply(DATAFRAMES, function(iter){
  thres=seq(5,95,1)
  RES=list()
  RES2=list()
  dff=iter$df
  MS=iter$MS
  for (i in 1:length(thres)) {
    dfi=data.frame(MF=dff$Weighted_EMF6_final_PacBio,nMS=apply(MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=thres[i]),threshold=thres[i])
    RES[[i]]=dfi
    dfii=as.data.frame(lapply(dfi, scale))
    mdl=lm(data = dfii,MF~nMS)
    
    resi=lm.boot(mdl,10000)
    resi=data.frame(threshold=thres[i],
                    coefs=unlist(lapply(resi$boot.list, function(mm) return(mm$coef[2]))),
                    R2=unlist(lapply(resi$boot.list, function(mm) return(mm$rsquare))))
    RES2[[i]]=resi
  }
  RES=do.call(rbind,RES)
  RES2=do.call(rbind,RES2)
  return(list(resultsdf=RES,resultscoef=RES2))
})

super.RES$global1a$resultsdf$ori.DF="Global #1a"
super.RES$global1a$resultscoef$ori.DF="Global #1a"
super.RES$global1b$resultsdf$ori.DF="Global #1b"
super.RES$global1b$resultscoef$ori.DF="Global #1b"
super.RES$global2$resultsdf$ori.DF="Global #2"
super.RES$global2$resultscoef$ori.DF="Global #2"


RES=do.call(rbind,lapply(super.RES, function(x) return(x$resultsdf))) #contains dff
RES2=do.call(rbind,lapply(super.RES, function(x) return(x$resultscoef))) #contains effect sizes

mytable=RES2 %>% group_by(threshold,ori.DF) %>% summarise(Average.R2=mean(R2),
                                                          sd.R2=sd(R2),
                                                          pval=ifelse(mean(coefs<0),sum(coefs<0),sum(coefs>0)),
                                                          Average.coef=mean(coefs),
                                                          ci.025=quantile(coefs,0.005),
                                                          ci.975=quantile(coefs,0.995))
write.csv(x = mytable,file = "pvalsrels.v5.csv",row.names = F)
write.csv(x = RES2,file = "allbootstraps.v5.csv",row.names = F)
write.csv(x = RES,file = "alldfs.v5.csv",row.names = F)

RES=read.csv("alldfs.v5.csv")
RES2=read.csv("allbootstraps.v5.csv")


#Simple plot
p1<-ggplot(data = RES,aes(x = nMS,y=MF,group=threshold,color=threshold))+
  theme_classic()+
  geom_smooth(method = "lm",se = F,size=0.2)+
  scale_color_gradientn(colours = rainbow(5,rev = T))+
  xlab("\nNumber of stressors\n above threshold")+
  ylab("Multiservices\n")+
  facet_wrap(~ori.DF,scales = "free")+
  theme(strip.background = element_blank(),
        strip.text = element_text(face = "bold"))


p2<-ggplot(data = mytable,aes(x = threshold,y=Average.R2))+
  theme_classic()+
  geom_line()+
  geom_ribbon(aes(x=threshold, ymin=ci.025, ymax=ci.975), fill="grey", alpha=.4) +
  geom_hline(yintercept = 0,color="red")+
  xlab("\nThreshold used \nfor stressors")+
  ylab("Standardized effect of number \nof stressors on Multiservices\n")+
  facet_wrap(~ori.DF,scales = "free")+
  theme(strip.background = element_blank(),
        strip.text = element_text(face = "bold"))

library(ggforce)
library(gridExtra)
PP1=grid.arrange(p1, p2, nrow = 2)

###Figure 2

library(gvlma)
library(MASS)
library(caret)
library(car)
library(vegan)
library(randomForest)
set.seed(100)

super.MOD=lapply(DATAFRAMES, function(iter){
  dff=iter$df
  dff$MS25=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=25)
  dff$MS50=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=50)
  dff$MS75=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=75)
  dfi=dff[,c("Weighted_EMF6_final_PacBio","MS25","MS50","MS75")]
  dfi=cbind(dfi,iter$MS)
  
  mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~.)
  assumptions=gvlma(mdl)
  vif.res=vif(mdl)
  RIMP=calc.relimp(mdl)
  R2=RIMP@R2
  RIMP=data.frame(variable=names(RIMP@lmg),lmg.imp=RIMP@lmg,perc.imp=RIMP@lmg/RIMP@R2)
  train=sample(1:nrow(dfi),size = floor(nrow(dfi)*0.7))
  validid=(1:nrow(dfi))
  validid=validid[!(validid %in% train)]
  
  rf.mod=randomForest(x=dfi[train,2:ncol(dfi)], y=dfi$Weighted_EMF6_final_PacBio[train],
                      xtest=dfi[validid,2:ncol(dfi)], ytest=dfi$Weighted_EMF6_final_PacBio[validid],
                      importance = T,ntree = 500)
  RIMP$RF.importance=rf.mod$importance[match(RIMP$variable,row.names(rf.mod$importance)),2]
  RIMP$RF.importance.perc=rf.mod$importance[match(RIMP$variable,row.names(rf.mod$importance)),2]/sum(rf.mod$importance[,2])
  
  
  #mumin
  options(na.action = "na.fail")
  dr1=dredge(mdl,rank="BIC",extra = "R^2")
  dr2=subset(dr1, delta < 4)
  
  ##CCA
  vars=c("OM_decomposition_final","Soil_Respiration_final","Habitat_final_PacBio","NPP_final","Nutrient_pools_final","Infiltration_final","Pathogen_control_final_PacBio")
  vars=vars[vars %in% names(dff)]
  vare.cca <- cca(dff[,vars] ~ ., data=iter$MS)
  
  return(list(cca.anal=vare.cca,assumpions.tests=list(assumptions=assumptions,inflation=vif.res),relative.imp=RIMP,R2=R2,MuMIN.mod=dr2))
})



super.MOD$global1a$relative.imp$ori.DF="Global #1a"
super.MOD$global1a$MuMIN.mod$ori.DF="Global #1a"
super.MOD$global1b$relative.imp$ori.DF="Global #1b"
super.MOD$global1b$MuMIN.mod$ori.DF="Global #1b"
super.MOD$global2$relative.imp$ori.DF="Global #2"
super.MOD$global2$MuMIN.mod$ori.DF="Global #2"



RES=do.call(rbind,lapply(super.MOD, function(x){
  d.out=x$relative.imp
  d.out$variable=as.factor(d.out$variable)
  d.out$variable.new=factor(d.out$variable,levels=levels(d.out$variable)[c(4,5,6,1,9,10,2,8,7,3)])
  levels(d.out$variable.new)=c("Multi-stressor >25%",
                               "Multi-stressor >50%",
                               "Multi-stressor >75%",
                               "Aridity",
                               "Seasonality",
                               "Temperature",
                               "Heavy metals",
                               "Salinity",
                               "Distance from neutral pH",
                               "Human influence"
  )
  d.out=d.out[order(d.out$variable.new),]
  d.out <- d.out %>% 
    mutate(csum = rev(cumsum(rev(perc.imp))), 
           pos = perc.imp/2 + lead(csum, 1),
           pos = if_else(is.na(pos), perc.imp/2, pos))
  return(d.out)
} )) #contains relative importance

RES=RES[!RES$ori.DF=="Global #1b",]

palete=c("#336600","#339900","#66CC33","#990000","#CC0000","#FF0000","#003399","#3366CC","#6699FF","#CCCC00")
blindpalete=c("#117733","#999933","#44AA99","#CC6677","#882255","#AA4499","#332288","#6699CC","#88CCEE","#DDCC77")

library(ggrepel)
p<-ggplot(data = RES,aes(x = 1,y=perc.imp,fill=variable.new))+
  theme_void()+
  geom_bar(stat="identity")+
  geom_label_repel(aes(y = pos, label = paste0(round(perc.imp,3)*100, "%")),
                   size = 3, nudge_x = 1, show.legend = FALSE,fill=NA)+
  coord_polar(theta = "y") +
  xlab("")+
  scale_fill_manual(values = blindpalete)+
  facet_wrap(~ori.DF)
p


####Figure 4 and supp table 4
RES=list()


iter=DATAFRAMES$global1a
dff=iter$df
dff$MS25=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=25)
dff$MS50=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=50)
dff$MS75=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=75)
dfi=dff[,c("Weighted_EMF6_final_PacBio","MS25","MS50","MS75")]
dfi=cbind(dfi,iter$MS)


mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Temperature*MS75) #0.04
mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Aridity*MS75) ##0.03
mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Seasonality*MS75) #0.04

summary(mdl)

dfi$type="Low MS75"
dfi$type[dfi$MS75>median(dfi$MS75)]="High MS75"

RES[[1]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Temperature,type=dfi$type,variable="Temperature",DF="Global #1a")
RES[[2]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Aridity,type=dfi$type,variable="Aridity",DF="Global #1a")
RES[[3]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Seasonality,type=dfi$type,variable="Seasonality",DF="Global #1a")

##NOW Global2

iter=DATAFRAMES$global2
dff=iter$df
dff$MS25=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=25)
dff$MS50=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=50)
dff$MS75=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=75)
dfi=dff[,c("Weighted_EMF6_final_PacBio","MS25","MS50","MS75")]
dfi=cbind(dfi,iter$MS)


mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Temperature*MS75) #NS
mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Aridity*MS75) ##NS
mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~Seasonality*MS75) #NS

summary(mdl)

dfi$type="Low MS75"
dfi$type[dfi$MS75>median(dfi$MS75)]="High MS75"

RES[[4]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Temperature,type=dfi$type,variable="Temperature",DF="Global #2")
RES[[5]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Aridity,type=dfi$type,variable="Aridity",DF="Global #2")
RES[[6]]=data.frame(y=dfi$Weighted_EMF6_final_PacBio,x=dfi$Seasonality,type=dfi$type,variable="Seasonality",DF="Global #2")

RES=do.call(rbind,RES)

##PLOT


p<-ggplot(data = RES,aes(x=x,y=y,group=type,color=as.factor(type)))+
  theme_bw()+
  geom_point()+
  geom_smooth(method="lm")+
  ylab("Multiservices")+
  xlab("Environmental factor level\n (% unitless)")+
  scale_color_manual(values = c("darkred","royalblue"),labels=c("High number of stressors above 75%","Low number of stressors above 75%"))+
  theme(legend.title = element_blank(),
        legend.position = "top")+
  facet_grid(DF~variable)

p



###Supp table 7: maintain in the model all stressors
##Issue nn: Maintain in the model all stressors

set.seed(100)

super.MOD=lapply(DATAFRAMES, function(iter){
  dff=iter$df
  dff$MS25=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=25)
  dff$MS50=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=50)
  dff$MS75=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=75)
  dfi=dff[,c("Weighted_EMF6_final_PacBio","MS25","MS50","MS75")]
  dfi=cbind(dfi,iter$MS)
  
  mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~.)
  assumptions=gvlma(mdl)
  vif.res=vif(mdl)
  RIMP=calc.relimp(mdl)
  RIMP=data.frame(variable=names(RIMP@lmg),lmg.imp=RIMP@lmg,perc.imp=RIMP@lmg/RIMP@R2)
  train=sample(1:nrow(dfi),size = floor(nrow(dfi)*0.7))
  validid=(1:nrow(dfi))
  validid=validid[!(validid %in% train)]
  
  rf.mod=randomForest(x=dfi[train,2:ncol(dfi)], y=dfi$Weighted_EMF6_final_PacBio[train],
                      xtest=dfi[validid,2:ncol(dfi)], ytest=dfi$Weighted_EMF6_final_PacBio[validid],
                      importance = T,ntree = 500)
  RIMP$RF.importance=rf.mod$importance[match(RIMP$variable,row.names(rf.mod$importance)),2]
  RIMP$RF.importance.perc=rf.mod$importance[match(RIMP$variable,row.names(rf.mod$importance)),2]/sum(rf.mod$importance[,2])
  
  
  #mumin
  options(na.action = "na.fail")
  dr1=pdredge(mdl,rank="BIC",fixed=c("Heavy_metals","Ph_neutro","Salinity","Seasonality","Temperature","Aridity","Human.activities"))
  dr2=subset(dr1, delta < 4)
  
  ##CCA
  vars=c("OM_decomposition_final","Soil_Respiration_final","Habitat_final_PacBio","NPP_final","Nutrient_pools_final","Infiltration_final","Pathogen_control_final_PacBio")
  vars=vars[vars %in% names(dff)]
  vare.cca <- cca(dff[,vars] ~ ., data=iter$MS)
  
  return(list(cca.anal=vare.cca,assumpions.tests=list(assumptions=assumptions,inflation=vif.res),relative.imp=RIMP,MuMIN.mod=dr2))
})



super.MOD$global1a$relative.imp$ori.DF="Global #1a"
super.MOD$global1a$MuMIN.mod$ori.DF="Global #1a"
super.MOD$global1b$relative.imp$ori.DF="Global #1b"
super.MOD$global1b$MuMIN.mod$ori.DF="Global #1b"
super.MOD$global2$relative.imp$ori.DF="Global #2"
super.MOD$global2$MuMIN.mod$ori.DF="Global #2"

summary(model.avg(super.MOD$global2$MuMIN.mod))


###Supp table 5. Variance inflation factors
iter=DATAFRAMES$global2

dff=iter$df
dff$MS25=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=25)
dff$MS50=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=50)
dff$MS75=apply(iter$MS, 1, function(rr,tt)return(sum(rr>=tt)),tt=75)
dfi=dff[,c("Weighted_EMF6_final_PacBio","MS25","MS50","MS75")]
dfi=cbind(dfi,iter$MS)

mdl=lm(data = dfi,Weighted_EMF6_final_PacBio~.)
assumptions=gvlma(mdl)
vif.res=vif(mdl)

vif.res
summary(mdl)

mdl=lm(data = dfi[,-2],Weighted_EMF6_final_PacBio~.)
assumptions=gvlma(mdl)
vif.res=vif(mdl)

vif.res
summary(mdl)

mdl=lm(data = dfi[,-c(3,9)],Weighted_EMF6_final_PacBio~.)
assumptions=gvlma(mdl)
vif.res=vif(mdl)

vif.res
summary(mdl)

mdl=lm(data = dfi[,-c(3,9,2)],Weighted_EMF6_final_PacBio~.)
assumptions=gvlma(mdl)
vif.res=vif(mdl)

vif.res
summary(mdl)

